@@ -1,5 +1,7 @@
 #define DEFINED_CONSTANT 10
 
+#include <stdint.h>
+
 enum {
   ENUMERATED_CONSTANT = 20
 };
@@ -23,3 +25,9 @@ struct idname
   int id;
   char name[12];
 };
+
+struct llq
+{
+  uint32_t l1, l2;
+  uint64_t q;
+};
